@@ -1,5 +1,5 @@
 /*
- * Copyright (C)2005-2012 Haxe Foundation
+ * Copyright (C)2005-2017 Haxe Foundation
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -36,10 +36,6 @@
 #define tmp_alloc(size) malloc(size)
 #define tmp_free(ptr)	free(ptr)
 
-#if defined(NEKO_X86) && !defined(NEKO_MAC)
-#define JIT_ENABLE
-#endif
-
 #ifdef NEKO_MAC
 #define STACK_ALIGN
 #endif
@@ -49,11 +45,9 @@
 #define STACK_ALIGN_DEBUG
 #endif
 
-#define TAG_MASK		((1<<TAG_BITS)-1)
+#define TAG_MASK		((1<<NEKO_TAG_BITS)-1)
 
-//#define JIT_DEBUG
-
-#ifdef JIT_ENABLE
+#ifdef NEKO_JIT_ENABLE
 
 #define PARAMETER_TABLE
 #include "opcodes.h"
@@ -579,7 +573,7 @@ static void debug_method_call( int line, int stack ) {
 }
 #endif
 
-#ifdef JIT_DEBUG
+#ifdef NEKO_JIT_DEBUG
 
 static void val_print_2( value v ) {
 	val_print(alloc_string(" "));
@@ -960,7 +954,7 @@ static void jit_call_prim( jit_ctx *ctx, int nargs, int mode ) {
 	for(i=0;i<nargs;i++) {
 		XPush_p(SP,FIELD(i));
 	}
-#	ifndef JIT_DEBUG
+#	ifndef NEKO_JIT_DEBUG
 	pop(nargs);
 #	endif
 
@@ -971,7 +965,7 @@ static void jit_call_prim( jit_ctx *ctx, int nargs, int mode ) {
 	end_call();
 	restore_after_call(nargs,pad_size);
 
-#	ifdef JIT_DEBUG
+#	ifdef NEKO_JIT_DEBUG
 	pop(nargs);
 #	endif
 	XRet();
@@ -1504,7 +1498,7 @@ static void jit_array_access( jit_ctx *ctx, int n ) {
 
 	XJump(JNeq,jnot_array);
 	if( n > 0 ) {
-		XUShr_rc(TMP,TAG_BITS);
+		XUShr_rc(TMP,NEKO_TAG_BITS);
 		XCmp_rc(TMP,n);
 		XJump(JLte,jbounds);
 	}
@@ -1621,58 +1615,70 @@ static void jit_make_env( jit_ctx *ctx, int esize ) {
 
 static void jit_object_op_gen( jit_ctx *ctx, enum Operation op, int right ) {
 	int *next;
+	field f;
+	int is_opset;
+
 	INIT_BUFFER;
 
+	f = 0;
+	is_opset = 0;
+	switch( op ) {
+	case OP_ADD:
+		f = (right ? id_radd : id_add);
+		break;
+	case OP_SUB:
+		f = (right ? id_rsub : id_sub);
+		break;
+	case OP_MUL:
+		f = (right ? id_rmult : id_mult);
+		break;
+	case OP_DIV:
+		f = (right ? id_rdiv : id_div);
+		break;
+	case OP_MOD:
+		f = (right ? id_rmod : id_mod);
+		break;
+	case OP_GET:
+		f = id_get;
+		break;
+	case OP_SET:
+		f = id_set;
+		is_opset = 1;
+		break;
+	default:
+		ERROR;
+	}
+
 	// prepare args
 	XPush_r(right?REG_TMP:REG_ACC);
-	if( op == OP_SET ) {
+	if( is_opset ) {
 		XMov_rp(TMP2,Esp,FIELD(3));
 		XPush_r(TMP2);
 	}
 	XMov_rr(TMP2,Esp);
 	XPush_c(0);
-	XPush_c((op == OP_SET)?2:1);
+	XPush_c(is_opset?2:1);
 	XPush_r(TMP2);
-	switch( op ) {
-	case OP_ADD:
-		XPush_c(right?id_radd:id_add);
-		break;
-	case OP_SUB:
-		XPush_c(right?id_rsub:id_sub);
-		break;
-	case OP_MUL:
-		XPush_c(right?id_rmult:id_mult);
-		break;
-	case OP_DIV:
-		XPush_c(right?id_rdiv:id_div);
-		break;
-	case OP_MOD:
-		XPush_c(right?id_rmod:id_mod);
-		break;
-	case OP_GET:
-		XPush_c(id_get);
-		break;
-	case OP_SET:
-		XPush_c(id_set);
-		break;
-	default:
-		ERROR;
-	}
+	XPush_r(right?REG_ACC:REG_TMP);
+
+	XPush_c(f);
 	XPush_r(right?REG_ACC:REG_TMP);
 	XCall_m(val_field);
+	stack_pop(Esp,2);
 	XCmp_rc(ACC,CONST(val_null));
 	XJump(JNeq,next);
-	stack_pop(Esp,(op == OP_SET)?7:6);
+	stack_pop(Esp,is_opset?6:5);
 	runtime_error(11,true); // Unsupported operation
+
 	PATCH_JUMP(next);
 	XPop_r(TMP);
-	stack_pop(Esp,1);
+
 	XPush_r(ACC);
 	XPush_r(TMP);
 	begin_call();
 	XCall_m(val_callEx);
 	end_call();
-	stack_pop(Esp,(op == OP_SET)?7:6);
+	stack_pop(Esp,is_opset?7:6);
 	XRet();
 	END_BUFFER;
 }
@@ -1728,7 +1734,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 	case AccEnv:
 		get_var_r(TMP,VEnv);
 		XMov_rp(TMP2,TMP,FIELD(0));
-		XCmp_rc(TMP2,(p << TAG_BITS) | VAL_ARRAY);
+		XCmp_rc(TMP2,(p << NEKO_TAG_BITS) | VAL_ARRAY);
 		XJump(JGt,jok);
 		runtime_error(1,false); // Reading Outside Env
 		PATCH_JUMP(jok);
@@ -1751,7 +1757,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 		// check bounds & access array
 		XShr_rc(ACC,1);
 		XMov_rp(TMP2,TMP,FIELD(0));
-		XUShr_rc(TMP2,TAG_BITS);
+		XUShr_rc(TMP2,NEKO_TAG_BITS);
 		XCmp_rr(ACC,TMP2);
 		XJump(JGte,jbounds);
 		XAdd_rc(ACC,1);			  // acc = val_array_ptr(tmp)[acc]
@@ -1868,7 +1874,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 	case SetEnv:
 		get_var_r(TMP,VEnv);
 		XMov_rp(TMP2,TMP,FIELD(0));
-		XCmp_rc(TMP2,(p << TAG_BITS) | VAL_ARRAY);
+		XCmp_rc(TMP2,(p << NEKO_TAG_BITS) | VAL_ARRAY);
 		XJump(JGt,jok);
 		runtime_error(2,false); // Writing Outside Env
 		PATCH_JUMP(jok);
@@ -1920,7 +1926,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 
 		XMov_rp(TMP,TMP,FIELD(0)); // tmp = tmp->type
 		XShr_rc(TMP2,1);
-		XUShr_rc(TMP,TAG_BITS);
+		XUShr_rc(TMP,NEKO_TAG_BITS);
 		XCmp_rr(TMP2,TMP);
 		XJump(JGte,jend1);
 
@@ -1969,7 +1975,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 		XJump(JNeq,jnot_array);
 
 		XMov_rp(TMP2,TMP,FIELD(0));
-		XCmp_rc(TMP2,(p << TAG_BITS) | VAL_ARRAY); // fake header
+		XCmp_rc(TMP2,(p << NEKO_TAG_BITS) | VAL_ARRAY); // fake header
 		XJump(JLte,jend1);
 		XMov_pr(TMP,FIELD(p + 1),ACC);
 		XJump_near(jend2);
@@ -2516,7 +2522,7 @@ static void jit_opcode( jit_ctx *ctx, enum OPCODE op, int p ) {
 }
 
 
-#if defined(STACK_ALIGN_DEBUG) || defined(JIT_DEBUG)
+#if defined(STACK_ALIGN_DEBUG) || defined(NEKO_JIT_DEBUG)
 #	define MAX_OP_SIZE		1000
 #	define MAX_BUF_SIZE		1000
 #else
@@ -2670,7 +2676,7 @@ void neko_module_jit( neko_module *m ) {
 		}
 
 		// --------- debug ---------
-#		ifdef JIT_DEBUG
+#		ifdef NEKO_JIT_DEBUG
 		if( ctx->debug_wait )
 			ctx->debug_wait--;
 		else {
@@ -2732,7 +2738,7 @@ void neko_module_jit( neko_module *m ) {
 		m->jit_gc = alloc_abstract(NULL,rbuf);
 		val_gc(m->jit_gc,free_jit_abstract);
 #		endif
-#		ifdef JIT_DEBUG
+#		ifdef NEKO_JIT_DEBUG
 		printf("Jit size = %d ( x%.1f )\n",csize,csize * 1.0 / ((m->codesize + 1) * 4));
 #		endif
 		jit_finalize_context(ctx);
@@ -2752,7 +2758,7 @@ void neko_module_jit( neko_module *m ) {
 	tmp_free(ctx->pos);
 }
 
-#else // JIT_ENABLE
+#else // NEKO_JIT_ENABLE
 
 char *jit_boot_seq = NULL;
 char *jit_handle_trap = (char*)&jit_boot_seq;
